==> stupidbuild-6.0.tar.xz: stupidbuild-6.0/src/mingw/w32-cpython2.7-lib-1.0-5/mingw/var/lib/mingw-get/scripts/w32-cpython2.7-lib-1.0-2-post-install.sh <==
#!/bin/sh
prefix=/mingw
pyprefix=$(/mingw/bin/python -c "import sys;print sys.prefix.replace('\\\\','/')")
pyver2dot=$(/mingw/bin/python -c "import sys;print str(sys.version_info[0]) + '.' + str(sys.version_info[1])")
pyver2=$(/mingw/bin/python -c "import sys;print str(sys.version_info[0]) + str(sys.version_info[1])")
sysroot="$SystemRoot"
if test -z "$sysroot"
then
  sysroot="$SYSTEMROOT"
fi
if test -z "$sysroot"
then
  echo "System roots \"$SystemRoot\" and \"$SYSTEMROOT\" are empty"
  exit 1
fi
sysroot="$(echo $sysroot | sed -e 's!\\!/!')"
system32="${sysroot}/System32"
syswow64="${sysroot}/SysWOW64"
pyarch=$(/mingw/bin/python -c "import platform;print platform.architecture()[0]")
if test "x${pyarch}" == "x32bit" -a -d ${syswow64}
then
  system32="${syswow64}"
fi

if test ! -e "/mingw/lib/libpython${pyver2dot}.dll.a"
then
   echo "pexports '${system32}/python${pyver2}.dll' > '${pyprefix}/libs/libpython${pyver2}.def'"
   pexports "${system32}/python${pyver2}.dll" > "${pyprefix}/libs/libpython${pyver2}.def"
   echo dlltool "${system32}/python${pyver2}.dll" -l "${prefix}/lib/libpython${pyver2dot}.dll.a" -d "${pyprefix}/libs/libpython${pyver2}.def"
   dlltool "${system32}/python${pyver2}.dll" -l "${prefix}/lib/libpython${pyver2dot}.dll.a" -d "${pyprefix}/libs/libpython${pyver2}.def"
fi

if test ! -e "/mingw/lib/libpython${pyver2}.dll.a"
then
   ln -s "libpython${pyver2dot}.dll.a" "${prefix}/lib/libpython${pyver2}.dll.a"
fi

wget --no-check-certificate https://bitbucket.org/pypa/setuptools/raw/bootstrap/ez_setup.py -O - | /mingw/bin/python

pushd /mingw/lib/python${pyver2dot}
  patch -N -p0 -i /mingw/share/w32-cpython/dont-use-msvcr-for-extensions.mingw.patch
  patchresult=$?
  if test "x$patchresult" != "x0"
  then
    patch -N -p0 -i /mingw/share/w32-cpython/dont-use-msvcr-for-extensions.mingw.patch | grep "Reversed (or previously applied) patch detected!"
    patchresult=$?
  fi
popd
if test "x$patchresult" != "x0"
then
  exit 1
fi

==> stupidbuild-6.0.1.tar.xz: stupidbuild-6.0.1/src/mingw/w32-cpython2.7-lib-1.0-6/mingw/var/lib/mingw-get/scripts/w32-cpython2.7-lib-1.0-3-post-install.sh <==
#!/bin/sh
prefix=/mingw
pyprefix=$(/mingw/bin/python -c "import sys;print sys.prefix.replace('\\\\','/')")
pyver2dot=$(/mingw/bin/python -c "import sys;print str(sys.version_info[0]) + '.' + str(sys.version_info[1])")
pyver2=$(/mingw/bin/python -c "import sys;print str(sys.version_info[0]) + str(sys.version_info[1])")
sysroot="$SystemRoot"
if test -z "$sysroot"
then
  sysroot="$SYSTEMROOT"
fi
if test -z "$sysroot"
then
  echo "System roots \"$SystemRoot\" and \"$SYSTEMROOT\" are empty"
  exit 1
fi
sysroot="$(echo $sysroot | sed -e 's!\\!/!')"
system32="${sysroot}/System32"
syswow64="${sysroot}/SysWOW64"
pyarch=$(/mingw/bin/python -c "import platform;print platform.architecture()[0]")
if test "x${pyarch}" == "x32bit" -a -d ${syswow64}
then
  system32="${syswow64}"
fi

if test ! -e "/mingw/lib/libpython${pyver2dot}.dll.a"
then
   pushd ~
     echo "pexports '${system32}/python${pyver2}.dll' > '${pyprefix}/libs/libpython${pyver2}.def'"
     pexports "${system32}/python${pyver2}.dll" > "${pyprefix}/libs/libpython${pyver2}.def"
     echo dlltool "${system32}/python${pyver2}.dll" -l "./libpython${pyver2dot}.dll.a" -d "${pyprefix}/libs/libpython${pyver2}.def"
     dlltool "${system32}/python${pyver2}.dll" -l "./libpython${pyver2dot}.dll.a" -d "${pyprefix}/libs/libpython${pyver2}.def"
     echo /usr/bin/install "./libpython${pyver2dot}.dll.a" "${prefix}/lib/libpython${pyver2dot}.dll.a"
     /usr/bin/install "./libpython${pyver2dot}.dll.a" "${prefix}/lib/libpython${pyver2dot}.dll.a" && rm -f "./libpython${pyver2dot}.dll.a"
   popd
fi

if test ! -e "/mingw/lib/libpython${pyver2}.dll.a"
then
   ln -s "libpython${pyver2dot}.dll.a" "${prefix}/lib/libpython${pyver2}.dll.a"
fi

pushd ~
  wget --no-check-certificate https://bitbucket.org/pypa/setuptools/raw/bootstrap/ez_setup.py -O - | /mingw/bin/python
popd

pushd /mingw/lib/python${pyver2dot}
  patch -N -p0 -i /mingw/share/w32-cpython/dont-use-msvcr-for-extensions.mingw.patch
  patchresult=$?
  if test "x$patchresult" != "x0"
  then
    patch -N -p0 -i /mingw/share/w32-cpython/dont-use-msvcr-for-extensions.mingw.patch | grep "Reversed (or previously applied) patch detected!"
    patchresult=$?
  fi
popd
if test "x$patchresult" != "x0"
then
  exit 1
fi
